==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ColumnSupportingCalculationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnSupportingCalculationDescription } from "./ColumnSupportingCalculationDescription";
/**
 * @hidden
 */
export let ColumnSupportingCalculationDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnSupportingCalculationDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnSupportingCalculationDescriptionMetadata.a == null) {
                ColumnSupportingCalculationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnSupportingCalculationDescriptionMetadata.c(ColumnSupportingCalculationDescriptionMetadata.a);
            }
            if (a.k(ColumnSupportingCalculationDescriptionMetadata.a)) {
                return;
            }
            a.aa(ColumnSupportingCalculationDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ColumnSupportingCalculationDescriptionMetadata.b(a);
            a.ac("ColumnSupportingCalculation", () => new ColumnSupportingCalculationDescription());
            a.ab("ColumnSupportingCalculation", ColumnSupportingCalculationDescriptionMetadata.a);
        }
    }
    ColumnSupportingCalculationDescriptionMetadata.$t = /*@__PURE__*/ markType(ColumnSupportingCalculationDescriptionMetadata, 'ColumnSupportingCalculationDescriptionMetadata');
    ColumnSupportingCalculationDescriptionMetadata.a = null;
    return ColumnSupportingCalculationDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/ColumnSupportingCalculationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnSupportingCalculationDescription } from "./ColumnSupportingCalculationDescription";
/**
 * @hidden
 */
export let ColumnSupportingCalculationDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnSupportingCalculationDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnSupportingCalculationDescriptionMetadata.a == null) {
                ColumnSupportingCalculationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnSupportingCalculationDescriptionMetadata.c(ColumnSupportingCalculationDescriptionMetadata.a);
            }
            if (a.k(ColumnSupportingCalculationDescriptionMetadata.a)) {
                return;
            }
            a.ac(ColumnSupportingCalculationDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ColumnSupportingCalculationDescriptionMetadata.b(a);
            a.ae("ColumnSupportingCalculation", () => new ColumnSupportingCalculationDescription());
            a.ad("ColumnSupportingCalculation", ColumnSupportingCalculationDescriptionMetadata.a);
        }
    }
    ColumnSupportingCalculationDescriptionMetadata.$t = /*@__PURE__*/ markType(ColumnSupportingCalculationDescriptionMetadata, 'ColumnSupportingCalculationDescriptionMetadata');
    ColumnSupportingCalculationDescriptionMetadata.a = null;
    return ColumnSupportingCalculationDescriptionMetadata;
})();
